@@ -37,7 +37,7 @@ class Tuple3(click.ParamType):
 
 @click.group()
 @click.option("-p", "--parallel", default=1, help="Run with this number of parallel processes. If 0, use number of cores.")
-@click.version_option(version="0.4.0")
+@click.version_option(version="0.4.1")
 @click.pass_context
 def main(ctx, parallel):
   """
@@ -112,8 +112,11 @@ def downsample(
     print("igneous: must choose one of --cseg or --compresso")
     sys.exit()
 
-  encoding = ("compressed_segmentation" if cseg else None)
-  encoding = ("compresso" if compresso else None)
+  encoding = None
+  if cseg:
+    encoding = "compressed_segmentation"
+  elif compresso:
+    encoding = "compresso"
 
   factor = (2,2,1)
   if volumetric:
@@ -182,8 +185,11 @@ def xfer(
     print("igneous: must choose one of --cseg or --compresso")
     sys.exit()
 
-  encoding = ("compressed_segmentation" if cseg else None)
-  encoding = ("compresso" if compresso else None)
+  encoding = None
+  if cseg:
+    encoding = "compressed_segmentation"
+  elif compresso:
+    encoding = "compresso"
 
   factor = (2,2,1)
   if volumetric:
